searchData={"items":[{"type":"module","title":"ExPoppy","doc":"Documentation for `ExPoppy`.\n\nExPoppy is a NIF wrapping the poppy RUST library https://github.com/hashlookup/poppy/ :\n- It allows for the creation and query of poppy and DCSO bloom filters\n- It comes with supervisor friendly worker that can hold a bloom filter in memory and answer client queries.","ref":"ExPoppy.html"},{"type":"function","title":"ExPoppy.capacity/1","doc":"Returns the filter capacity","ref":"ExPoppy.html#capacity/1"},{"type":"function","title":"Example - ExPoppy.capacity/1","doc":"ExPoppy.capacity(hashlookup)\n    405127458","ref":"ExPoppy.html#capacity/1-example"},{"type":"function","title":"ExPoppy.contains_str/2","doc":"Checks whether a `String` may be in the bloom filter.\nReturn `true` or `false`","ref":"ExPoppy.html#contains_str/2"},{"type":"function","title":"Examples - ExPoppy.contains_str/2","doc":"iex(3)> bf = ExPoppy.new(100000, 0.01)\n    iex(4)> ExPoppy.insert_str(bf, \"bloom filters are cool\")\n    iex(6)> ExPoppy.contains_str(bf, \"bloom filters are not cool.\")\n    false\n    iex(7)> ExPoppy.contains_str(bf, \"bloom filters are cool\")\n    true","ref":"ExPoppy.html#contains_str/2-examples"},{"type":"function","title":"ExPoppy.count_estimate/1","doc":"Returns the filter estimated number of items stored in the bloom filter.","ref":"ExPoppy.html#count_estimate/1"},{"type":"function","title":"Example - ExPoppy.count_estimate/1","doc":"iex(3)> bf = ExPoppy.new(1000, 0.001)\n    iex(4)> ExPoppy.insert_str(bf, \"bloom filters are cool\")\n    iex(11)> ExPoppy.count_estimate(bf)\n    1","ref":"ExPoppy.html#count_estimate/1-example"},{"type":"function","title":"ExPoppy.fpp/1","doc":"Returns the filter false positive rate","ref":"ExPoppy.html#fpp/1"},{"type":"function","title":"Example - ExPoppy.fpp/1","doc":"iex(3)> bf = ExPoppy.new(1000, 0.001)\n    iex(10)> ExPoppy.fpp(bf)\n    0.001","ref":"ExPoppy.html#fpp/1-example"},{"type":"function","title":"ExPoppy.insert_str/2","doc":"Inserts a `String` into the bloom filter.\nReturns `true` or a `{:error, \"a message describing the error\"}`","ref":"ExPoppy.html#insert_str/2"},{"type":"function","title":"Example - ExPoppy.insert_str/2","doc":"iex(3)> bf = ExPoppy.new(100000, 0.01)\n    iex(4)> ExPoppy.insert_str(bf, \"bloom filters are cool\")\n    true","ref":"ExPoppy.html#insert_str/2-example"},{"type":"function","title":"ExPoppy.load_filter/1","doc":"Loads the filters located at `String`\nReturns a `Reference` to the bloom filter or `{:error, \"a message describing the error\"}`","ref":"ExPoppy.html#load_filter/1"},{"type":"function","title":"Example - ExPoppy.load_filter/1","doc":"hashlookup = ExPoppy.load_filter(\"~/hashlookup-full.bloom\")\n    {:error, \"IO error: No such file or directory (os error 2)\"}\n    hashlookup = ExPoppy.load_filter(\"/home/jlouis/hashlookup-full.bloom\")\n    #Reference<0.2014093505.3446538246.36262>","ref":"ExPoppy.html#load_filter/1-example"},{"type":"function","title":"ExPoppy.new/2","doc":"Create a new bloom filter.\nReturns a `Reference` to the Bloom Filter or `{:error, \"a message describing the error\"}`","ref":"ExPoppy.html#new/2"},{"type":"function","title":"Examples - ExPoppy.new/2","doc":"ExPoppy.new(100000, 0.01)\n    #Reference<0.2530677463.222167047.167339>","ref":"ExPoppy.html#new/2-examples"},{"type":"function","title":"ExPoppy.save/2","doc":"Save the bloom filter to a file `String`\n\nReturns `{}` or {:error, \"a message describing the error\"}","ref":"ExPoppy.html#save/2"},{"type":"function","title":"Examples - ExPoppy.save/2","doc":"ExPoppy.save(bf, \"/home/jlouis/test.bloom\")\n    {}\n    ExPoppy.save(bf, \"/root/test.boom\")\n    {:error, \"IO error: Permission denied (os error 13)\"}","ref":"ExPoppy.html#save/2-examples"},{"type":"function","title":"ExPoppy.version/1","doc":"Returns the filter version","ref":"ExPoppy.html#version/1"},{"type":"function","title":"Example - ExPoppy.version/1","doc":"iex(3)> bf = ExPoppy.new(100000, 0.01)\n    iex(8)> ExPoppy.version(bf)\n    2","ref":"ExPoppy.html#version/1-example"},{"type":"function","title":"ExPoppy.with_params/4","doc":"Creates a new bloom filter, specifying the filter version, and additional parameters.\nSee `with_version` for a description of the `version` parameter.\n`opt` specifies how Poppy will optimize the bloom filter:\n- 0: no optimization (default),\n- 1: optimize for space,\n- 2: optimize for speed,\n- 3: best overall.\n\nReturns a `Reference` to the Bloom Filter or `{:error, \"a message describing the error\"}`","ref":"ExPoppy.html#with_params/4"},{"type":"function","title":"Examples - ExPoppy.with_params/4","doc":"ExPoppy.with_params(2, 10000, 0.001, 1)\n    #Reference<0.2014093505.3446538246.36083>","ref":"ExPoppy.html#with_params/4-examples"},{"type":"function","title":"ExPoppy.with_version/3","doc":"Creates a new bloom filter, specifying the filter version:\n - `1` for DCSO bloom filter format\n - `2` for poppyV2 bloom filter format\n\nSee https://www.misp-project.org/2024/03/25/Poppy-a-new-bloom-filter-format-and-project.html/ for a complete explanation of the differences.\n\nReturns a `Reference` to the Bloom Filter or `{:error, \"a message describing the error\"}`","ref":"ExPoppy.html#with_version/3"},{"type":"function","title":"Examples - ExPoppy.with_version/3","doc":"ExPoppy.with_version(1, 10000, 0.001)\n    #Reference<0.362273875.1027997698.75968>\n\n    ExPoppy.with_version(2, 10000, 0.001)\n    #Reference<0.362273875.1027997698.75988>","ref":"ExPoppy.html#with_version/3-examples"},{"type":"module","title":"ExPoppyServer","doc":"Documentation for `ExPoppyServer`.\n\nExPoppyServer is a genserver holding the reference to a `ExPoppy` bloom filter in memory.\nThe main purpose of this construct is to avoid reloading a filter when not necessary.\n\nHere is how one would add ExPoppyServer to an application's Supervisor to give access to a filter called `host.bloom`:\n\n`{ExPoppy.ExPoppyServer, name: :poppyserver, path: Path.join([:code.priv_dir(:myapp), \"host.bloom\"])}`","ref":"ExPoppyServer.html"},{"type":"function","title":"ExPoppyServer.capacity/1","doc":"Returns the filter's capacity","ref":"ExPoppyServer.html#capacity/1"},{"type":"function","title":"Examples - ExPoppyServer.capacity/1","doc":"iex(8)> ExPoppyServer.capacity(pid)\n    10000","ref":"ExPoppyServer.html#capacity/1-examples"},{"type":"function","title":"ExPoppyServer.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ExPoppyServer.html#child_spec/1"},{"type":"function","title":"ExPoppyServer.contains/2","doc":"Checks whether a `string` may be preesnt in the bloom filter.\nReturns `true` or `false`","ref":"ExPoppyServer.html#contains/2"},{"type":"function","title":"Examples - ExPoppyServer.contains/2","doc":"iex(5)> ExPoppyServer.contains(pid, \"toto\")\n    true\n    iex(6)> ExPoppyServer.contains(pid, \"tata\")\n    false","ref":"ExPoppyServer.html#contains/2-examples"},{"type":"function","title":"ExPoppyServer.count_estimate/1","doc":"Returns the estimate count of elements in the bloom filter","ref":"ExPoppyServer.html#count_estimate/1"},{"type":"function","title":"Examples - ExPoppyServer.count_estimate/1","doc":"iex(2)> ExPoppyServer.insert(pid, \"toto\")\n    :ok\n    iex(3)> ExPoppyServer.insert(pid, \"tata\")\n    :ok\n    iex(4)> ExPoppyServer.count_estimate(pid)\n    2","ref":"ExPoppyServer.html#count_estimate/1-examples"},{"type":"function","title":"ExPoppyServer.fpp/1","doc":"Returns the filter's false positive rate","ref":"ExPoppyServer.html#fpp/1"},{"type":"function","title":"Examples - ExPoppyServer.fpp/1","doc":"iex(8)> ExPoppyServer.fpp(pid)\n    0.001","ref":"ExPoppyServer.html#fpp/1-examples"},{"type":"function","title":"ExPoppyServer.insert/2","doc":"Inserts a `string` into the bloomfilter.\nReturns `:ok` or `{:error, \"a message describing the error}`","ref":"ExPoppyServer.html#insert/2"},{"type":"function","title":"Examples - ExPoppyServer.insert/2","doc":"iex(4)> ExPoppyServer.insert(pid, \"toto\")\n   :ok","ref":"ExPoppyServer.html#insert/2-examples"},{"type":"function","title":"ExPoppyServer.load/2","doc":"Loads the bloom filter located at `path`.\nReturns `:ok` or `{:error, \"a message describing the error\"}`\n# Examples\n    iex(5)> ExPoppyServer.load(pid, \"toto\")\n    :ok\n    iex(6)> ExPoppyServer.load(pid, \"/root/toto\")\n    {:error, \"IO error: Permission denied (os error 13)\"}\n    iex(8)> ExPoppyServer.load(pid, \"/home/jlouis/tata\")\n    {:error, \"IO error: No such file or directory (os error 2)\"}","ref":"ExPoppyServer.html#load/2"},{"type":"function","title":"ExPoppyServer.save/2","doc":"Saves the bloom filter to a file located at `path`\nReturns `:ok` or `{:error, \"a message describing the error\"}`","ref":"ExPoppyServer.html#save/2"},{"type":"function","title":"Examples - ExPoppyServer.save/2","doc":"iex(4)> ExPoppyServer.save(pid, \"toto\")\n    :ok\n    iex(6)> ExPoppyServer.save(pid, \"/root/toto\")\n    {:error, \"IO error: Permission denied (os error 13)\"}","ref":"ExPoppyServer.html#save/2-examples"},{"type":"function","title":"ExPoppyServer.start_link/1","doc":"Starts genserver.\nProcess name can be set in the options.","ref":"ExPoppyServer.html#start_link/1"},{"type":"function","title":"Examples - ExPoppyServer.start_link/1","doc":"iex(1)> {:ok, pid} = ExPoppyServer.start_link([])\n    {:ok, #PID<0.188.0>}\n    iex(4)> {:ok, pid2} = ExPoppyServer.start_link([])\n    ** (MatchError) no match of right hand side value: {:error, {:already_started, #PID<0.188.0>}}","ref":"ExPoppyServer.html#start_link/1-examples"},{"type":"function","title":"ExPoppyServer.version/1","doc":"Returns the filter's version","ref":"ExPoppyServer.html#version/1"},{"type":"function","title":"Examples - ExPoppyServer.version/1","doc":"iex(7)> ExPoppyServer.version(pid)\n    2","ref":"ExPoppyServer.html#version/1-examples"},{"type":"module","title":"PoppyPlug","doc":"Documentation for `PoppyPlug`.\n\nPoppyPlug filters out requests that match an `ExPoppy` bloom filter served by\nan `ExPoppyServer`. The fields to match on are passed to the plug through `opt`.\n\nFor instance to filter every requests for which the host may appear in the bloom filter:\n\n`plug(PoppyPlug, poppy_server: :plugfestpoppy, filter: :host)`","ref":"PoppyPlug.html"},{"type":"function","title":"PoppyPlug.call/2","doc":"","ref":"PoppyPlug.html#call/2"},{"type":"function","title":"PoppyPlug.init/1","doc":"","ref":"PoppyPlug.html#init/1"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}